==> jlessc-1.3-sources.jar: com/inet/lib/less/CssPlainOutput.java <==
/**
 * MIT License (MIT)
 *
 * Copyright (c) 2014 - 2015 Volker Berlin
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * UT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * @author Volker Berlin
 * @license: The MIT license <http://opensource.org/licenses/MIT>
 */
package com.inet.lib.less;

/**
 * A CSS output that has not the layout of a rule like comments and directives.
 */
class CssPlainOutput extends CssOutput {

    private StringBuilder output;

    /**
     * Create a new output sequence.
     * @param output a string builder to hold the plain output.
     */
    CssPlainOutput( StringBuilder output ) {
        this.output = output;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    void appendTo( StringBuilder target, LessExtendMap lessExtends, CssFormatter formatter ) {
        target.append( output );
    }
}

==> jlessc-1.5-sources.jar: com/inet/lib/less/CssPlainOutput.java <==
/**
 * MIT License (MIT)
 *
 * Copyright (c) 2014 - 2015 Volker Berlin
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * UT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * @author Volker Berlin
 * @license: The MIT license <http://opensource.org/licenses/MIT>
 */
package com.inet.lib.less;

/**
 * A CSS output that has not the layout of a rule like comments and directives.
 */
class CssPlainOutput extends CssOutput {

    private StringBuilder output;

    /**
     * Create a new output sequence.
     * @param output a string builder to hold the plain output.
     */
    CssPlainOutput( StringBuilder output ) {
        this.output = output;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    void appendTo( StringBuilder target, LessExtendMap lessExtends, CssFormatter formatter ) {
        target.append( output );
    }

    /**
     * {@inheritDoc}
     */
    @Override
    boolean hasContent(LessExtendMap lessExtends ) {
        return output.length() > 0;
    }

    /**
     * Get ever null for this type of CssOutput.
     * @return ever null
     */
    String[] getSelectors() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    StringBuilder getOutput() {
        return output;
    }
}
